.. This README is meant for consumption by humans and pypi. Pypi can render rst files so please do not use Sphinx features.
   If you want to learn more about writing documentation, please check out: http://docs.plone.org/about/documentation_styleguide.html
   This text does not appear on pypi or github. It is a comment.

==============================================================================
collective.disableuser
==============================================================================

.. image:: https://secure.travis-ci.org/collective/collective.disableuser.png
    :target: http://travis-ci.org/collective/collective.disableuser

.. image:: https://coveralls.io/repos/collective/collective.disableuser/badge.png?branch=master
    :target: https://coveralls.io/r/collective/collective.disableuser

.. image:: https://img.shields.io/pypi/v/collective.disableuser.svg
    :target: https://pypi.python.org/pypi/collective.disableuser/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/status/collective.disableuser.svg
    :target: https://pypi.python.org/pypi/collective.disableuser/
    :alt: Egg Status

.. image:: https://img.shields.io/pypi/l/collective.disableuser.svg
    :target: https://pypi.python.org/pypi/collective.disableuser/
    :alt: License


This Plone addon allows a site administrator to block and unblock users.

Features
--------

- Block/unblock users through the Plone User controlpanel
- Block/unblock users through a REST endpoint


Translations
------------

This product has been translated into

- English
- German


Installation
------------

Install collective.disableuser by adding it to your buildout::

    [buildout]

    ...

    eggs =
        collective.disableuser


and then running ``bin/buildout``


Contribute
----------

- Issue Tracker: https://github.com/collective/collective.disableuser/issues
- Source Code: https://github.com/collective/collective.disableuser
- Documentation: https://docs.plone.org/foo/bar


Credits
-------

.. image:: https://kitconcept.com/logo.png
   :height: 461px
   :width: 100px
   :scale: 100 %
   :alt: kitconcept
   :align: center
   :target: https://www.kitconcept.com/

This plugin is developed and maintained by `kitconcept`_.

If you are having issues, please let us know.


Support
-------

If you are having issues, please let us know via the github issue tracker at
https://github.com/collective/collective.disableuser/issues.


License
-------

The project is licensed under the GPLv2.


.. _`kitconcept`: https://kitconcept.com
